On 2007-02-23 16:40, "Frank Batschulat (Home)" <Frank.Batschulat at Sun.COM> 
wrote:
> On Fri, 23 Feb 2007 14:03:51 +0100, Giorgos Keramidas  
> <keramida at ceid.upatras.gr> wrote:
> 
> >Hi all,
> >
> >I have a patch in the works for bite-sized-bugs:
> >
> >6291460 too much pseudo-spelling in solaris (oss-bite-size)
> >6291454 speeling of pseudo is rong inside ON
> 
> hmm, the latter one is already integrated:
> 
> Commit To Fix In Build        snv_20
> Fixed In Build        snv_20
> Integrated In Build   snv_20

Oh, I missed that.  I'm not very acquainted with the states of bugs in
opensolaris.org, so forgive my oversight :)

There are still several mis-spellings of "pseudo" in the tree, which I
fixed with the attached patch.  I haven't run a full build yet, because
I managed to break my build machine at home last night, but this should
be easy to do later tonight.

Since most of the changes are in comments, I'm only worried about
breaking things with the change to usr/src/tools/cscope-fast/ files.

-------------- next part --------------
6291460 too much pseudo-spelling in solaris (oss-bite-size)
6291454 speeling of pseudo is rong inside ON

diff --git a/deleted_files/usr/src/cmd/pt_chmod/pt_chmod.c 
b/deleted_files/usr/src/cmd/pt_chmod/pt_chmod.c
--- a/deleted_files/usr/src/cmd/pt_chmod/pt_chmod.c
+++ b/deleted_files/usr/src/cmd/pt_chmod/pt_chmod.c
@@ -42,7 +42,7 @@
 
 /*
  * 1) change the owner and mode of the pseudo terminal slave device.
- * 2) (re)create nodes and devlinks for pseduo terminal slave device.
+ * 2) (re)create nodes and devlinks for pseudo terminal slave device.
  */
 int
 main(int argc, char **argv)
diff --git a/usr/src/cmd/cmd-inet/usr.lib/mipagent/aaa.c 
b/usr/src/cmd/cmd-inet/usr.lib/mipagent/aaa.c
--- a/usr/src/cmd/cmd-inet/usr.lib/mipagent/aaa.c
+++ b/usr/src/cmd/cmd-inet/usr.lib/mipagent/aaa.c
@@ -1950,7 +1950,7 @@ aaaGenerateSpi()
 {
        static uint32_t SPI = 0x80000000;
        return (SPI++);
-} /* return a psuedo random spi */
+} /* return a pseudo random spi */
 #endif  /* TEST_DIAMETER */
 
 /*
diff --git a/usr/src/cmd/enhance/enhance.c b/usr/src/cmd/enhance/enhance.c
--- a/usr/src/cmd/enhance/enhance.c
+++ b/usr/src/cmd/enhance/enhance.c
@@ -498,7 +498,7 @@ static int pty_stop_parent(int waserr, i
 
 /*.......................................................................
  * Run the user's program, with its stdin and stdout connected to the
- * slave end of the psuedo-terminal.
+ * slave end of the pseudo-terminal.
  *
  * Input:
  *  prog  const char *   The name of this program.
diff --git a/usr/src/cmd/expr/compile.c b/usr/src/cmd/expr/compile.c
--- a/usr/src/cmd/expr/compile.c
+++ b/usr/src/cmd/expr/compile.c
@@ -54,7 +54,7 @@
 #include <regexpr.h>
 
 /*
- * psuedo compile/step/advance global variables
+ * pseudo compile/step/advance global variables
  */
 extern int nbra;
 extern char *locs;             /* for stopping execess recursion */
diff --git a/usr/src/cmd/rpcsvc/nis/rpc.nisd/nis_db.c 
b/usr/src/cmd/rpcsvc/nis/rpc.nisd/nis_db.c
--- a/usr/src/cmd/rpcsvc/nis/rpc.nisd/nis_db.c
+++ b/usr/src/cmd/rpcsvc/nis/rpc.nisd/nis_db.c
@@ -661,7 +661,7 @@ cvt2object(
        entry_obj       *ep[],
        uint_t          num,
        int             *got,
-       int             mangle) /* Make non-entry objects into psuedo entries */
+       int             mangle) /* Make non-entry objects into pseudo entries */
 {
        register obj_list       *oa;            /* object array         */
        nis_object              *tmp;           /* Temporary object(s)  */
diff --git a/usr/src/cmd/rpcsvc/nis/rpc.nisd/nisinit.c 
b/usr/src/cmd/rpcsvc/nis/rpc.nisd/nisinit.c
--- a/usr/src/cmd/rpcsvc/nis/rpc.nisd/nisinit.c
+++ b/usr/src/cmd/rpcsvc/nis/rpc.nisd/nisinit.c
@@ -29,7 +29,7 @@
 /*
  * This module contains the nis initialization code. It is designed to
  * initialize a client or server. The server can be a master server or
- * a slave server (replicate). NOTE: This file defines what the "psuedo"
+ * a slave server (replicate). NOTE: This file defines what the "pseudo"
  * tables look like when defined by the server. This means that this
  * module and the nis_db.c module must track each other. This module
  * gets linked to nis_db.o and the database library.
diff --git a/usr/src/cmd/rpcsvc/nis/utils/nischmod.c 
b/usr/src/cmd/rpcsvc/nis/utils/nischmod.c
--- a/usr/src/cmd/rpcsvc/nis/utils/nischmod.c
+++ b/usr/src/cmd/rpcsvc/nis/utils/nischmod.c
@@ -195,7 +195,7 @@ main(int argc, char *argv[])
                break;
        case CMD_CHOWN:
                /*
-                * get the principal name using psuedo expand name
+                * get the principal name using pseudo expand name
                 * magic
                 */
                udata = argv[optind++];
@@ -229,7 +229,7 @@ main(int argc, char *argv[])
                break;
        case CMD_CHGRP:
                /*
-                * get the group name using psuedo expand name magic
+                * get the group name using pseudo expand name magic
                 */
                udata = argv[optind++];
                if ((plist = nis_getnames(udata)) == 0) {
diff --git a/usr/src/cmd/rpcsvc/nis/utils/nisgrpadm.c 
b/usr/src/cmd/rpcsvc/nis/utils/nisgrpadm.c
--- a/usr/src/cmd/rpcsvc/nis/utils/nisgrpadm.c
+++ b/usr/src/cmd/rpcsvc/nis/utils/nisgrpadm.c
@@ -237,7 +237,7 @@ main(int argc, char *argv[])
                }
        } else {
                /*
-                * Get the group name using psuedo expand name magic
+                * Get the group name using pseudo expand name magic
                 */
                if ((grplist = nis_getnames(grpname)) == 0) {
                        nis_perror(NIS_NOMEMORY, "nisgrpadm");
@@ -354,7 +354,7 @@ main(int argc, char *argv[])
                        }
                } else {
                        /*
-                        * Get the principal name using psuedo expand name
+                        * Get the principal name using pseudo expand name
                         * magic
                         */
                        if (plist)
diff --git a/usr/src/cmd/terminfo/termcap b/usr/src/cmd/terminfo/termcap
--- a/usr/src/cmd/terminfo/termcap
+++ b/usr/src/cmd/terminfo/termcap
@@ -613,7 +613,7 @@ Mo|omron|Omron 8025AG:\
        :so=\Ef:sr=\ET:up=\EA:ve=:vs=\EN:
 Mp|plasma|plasma panel:\
        :am:le=^H:bs:cl=^L:co#85:ho=^^:li#45:nd=\030:up=\026:do=^J:
-Mq|pty|psuedo teletype:\
+Mq|pty|pseudo teletype:\
        :do=^J:co#80:li#24:am:cl=\EJ:le=^H:bs:cm=\EG%+ %+ :nd=\EC:\
        :up=\EA:ce=\EK:cd=\EL:al=\EP:dl=\EN:ic=\EO:\
        :so=\Ea$:se=\Eb$:us=\Ea!:ue=\Eb!:
diff --git a/usr/src/cmd/vi/misc/ctags.c b/usr/src/cmd/vi/misc/ctags.c
--- a/usr/src/cmd/vi/misc/ctags.c
+++ b/usr/src/cmd/vi/misc/ctags.c
@@ -292,7 +292,7 @@ main(int ac, char *av[])
 }
 
 /*
- * This routine sets up the boolean psuedo-functions which work
+ * This routine sets up the boolean pseudo-functions which work
  * by seting boolean flags dependent upon the corresponding character
  * Every char which is NOT in that string is not a white char.  Therefore,
  * all of the array "_wht" is set to FALSE, and then the elements
@@ -1444,7 +1444,7 @@ char **av;                        /* ptr to original 
argument
        int a;                  /* used to parse combined arguments     */
        int fflag;              /* 1 = we're only parsing filenames     */
        size_t sz;              /* size of the argument                 */
-       size_t mav_sz;          /* size of our psuedo argument space    */
+       size_t mav_sz;          /* size of our pseudo argument space    */
 
        i = mac = fflag = 0;    /* proper initializations */
 
diff --git a/usr/src/cmd/vi/port/ex_vget.c b/usr/src/cmd/vi/port/ex_vget.c
--- a/usr/src/cmd/vi/port/ex_vget.c
+++ b/usr/src/cmd/vi/port/ex_vget.c
@@ -847,7 +847,7 @@ setalarm(void)
         * transmit faster than this.
         */
 
-       /* Open ft psuedo-device - we need our own copy. */
+       /* Open ft pseudo-device - we need our own copy. */
        if (ftfd == 0) {
                strcpy(ftname, "/dev/ft0");
                while (ftfd <= 0 && ftname[7] <= '~') {
diff --git a/usr/src/cmd/xntpd/libparse/README.parse_clocks 
b/usr/src/cmd/xntpd/libparse/README.parse_clocks
--- a/usr/src/cmd/xntpd/libparse/README.parse_clocks
+++ b/usr/src/cmd/xntpd/libparse/README.parse_clocks
@@ -123,7 +123,7 @@ in the parse/clk_*.c and xntpd/refclock_
 ---
     RAWDCF: 127.127.8.20-23 (Conrad receiver module - delay 210ms)
            127.127.8.24-27 (FAU receiver - delay 258ms)
-    RAWDCF: end=TIMEOUT>1.5s, sync each char (any char),generate psuedo time
+    RAWDCF: end=TIMEOUT>1.5s, sync each char (any char),generate pseudo time
             codes, fixed format
 
     direct DCF77 code input
@@ -155,7 +155,7 @@ in the parse/clk_*.c and xntpd/refclock_
        time marks of a 100ms duration constitute a logical 0
        time marks of a 200ms duration constitute a logical 1
        FM:
-       see the spec. (basically a (non-)inverted psuedo random phase shift)
+       see the spec. (basically a (non-)inverted pseudo random phase shift)
 
        Encoding:
        Second  Contents
diff --git a/usr/src/cmd/xntpd/libparse/clk_rawdcf.c 
b/usr/src/cmd/xntpd/libparse/clk_rawdcf.c
--- a/usr/src/cmd/xntpd/libparse/clk_rawdcf.c
+++ b/usr/src/cmd/xntpd/libparse/clk_rawdcf.c
@@ -59,7 +59,7 @@
  *     time marks of a 100ms duration constitute a logical 0
  *     time marks of a 200ms duration constitute a logical 1
  * FM:
- *     see the spec. (basically a (non-)inverted psuedo random phase shift)
+ *     see the spec. (basically a (non-)inverted pseudo random phase shift)
  *
  * Encoding:
  * Second      Contents
diff --git a/usr/src/grub/grub-0.95/NEWS b/usr/src/grub/grub-0.95/NEWS
--- a/usr/src/grub/grub-0.95/NEWS
+++ b/usr/src/grub/grub-0.95/NEWS
@@ -173,7 +173,7 @@ New in 0.5.96 - 2000-10-04:
 * The command-line interface is switched to single-line editing mode.
 * Only for developers: the configure script accepts
   `--enable-serial-speed-simulation', which is useful when you want to
-  simulate the speed of a serial device on a psuedo terminal.
+  simulate the speed of a serial device on a pseudo terminal.
 * Also only for developers: you can specify an optional argument to the
   option `--hold' for the grub shell. The argument means how many
   seconds the grub shell should wait until diving into the main routine.
diff --git a/usr/src/lib/libcurses/screen/napms.c 
b/usr/src/lib/libcurses/screen/napms.c
--- a/usr/src/lib/libcurses/screen/napms.c
+++ b/usr/src/lib/libcurses/screen/napms.c
@@ -62,7 +62,7 @@
  *     always unused that you have read permission on to sleep on.
  *
  * (3) Install the ft (fast timer) device in your kernel.
- *     This is a psuedo-device to which an ioctl will wait n ticks
+ *     This is a pseudo-device to which an ioctl will wait n ticks
  *     and then send you an alarm.
  *
  * (4) Install the nap system call in your kernel.
diff --git a/usr/src/lib/libnsl/nis/gen/nis_callback.c 
b/usr/src/lib/libnsl/nis/gen/nis_callback.c
--- a/usr/src/lib/libnsl/nis/gen/nis_callback.c
+++ b/usr/src/lib/libnsl/nis/gen/nis_callback.c
@@ -34,7 +34,7 @@
  *     facility. They are RPC library dependent.
  *
  *     These callback functions set up and run the callback
- *     facility of NIS+. The idea is simple, a psuedo service is created
+ *     facility of NIS+. The idea is simple, a pseudo service is created
  *     by the client and registered with the portmapper. The program number
  *     for that service is included in the request as is the principal
  *     name of the _host_ where the request is being made. The server
@@ -162,7 +162,7 @@ static struct timeval       __nis_dump_lastcb 
 
 /*
  * Callback functions. These functions set up and run the callback
- * facility of NIS. The idea is simple, a psuedo service is created
+ * facility of NIS. The idea is simple, a pseudo service is created
  * by the client and registered with the portmapper. The program number
  * for that service is included in the request as is the principal
  * name of the _host_ where the request is being made. The server
diff --git a/usr/src/lib/libnsl/rpc/clnt_raw.c 
b/usr/src/lib/libnsl/rpc/clnt_raw.c
--- a/usr/src/lib/libnsl/rpc/clnt_raw.c
+++ b/usr/src/lib/libnsl/rpc/clnt_raw.c
@@ -177,7 +177,7 @@ call_again:
        /*
         * We have to call server input routine here because this is
         * all going on in one process.
-        * By convention using FD_SETSIZE as the psuedo file descriptor.
+        * By convention using FD_SETSIZE as the pseudo file descriptor.
         */
        svc_getreq_common(FD_SETSIZE);
 
@@ -256,7 +256,7 @@ clnt_raw_send(CLIENT *h, rpcproc_t proc,
        /*
         * We have to call server input routine here because this is
         * all going on in one process.
-        * By convention using FD_SETSIZE as the psuedo file descriptor.
+        * By convention using FD_SETSIZE as the pseudo file descriptor.
         */
        svc_getreq_common(FD_SETSIZE);
 
diff --git a/usr/src/lib/libnsl/rpc/svc_raw.c b/usr/src/lib/libnsl/rpc/svc_raw.c
--- a/usr/src/lib/libnsl/rpc/svc_raw.c
+++ b/usr/src/lib/libnsl/rpc/svc_raw.c
@@ -109,7 +109,7 @@ svc_raw_create(void)
                return (NULL);
        }
        /*
-        * By convention, using FD_SETSIZE as the psuedo file descriptor
+        * By convention, using FD_SETSIZE as the pseudo file descriptor
         */
        srp->server->xp_fd = FD_SETSIZE;
        srp->server->xp_port = 0;
diff --git a/usr/src/lib/nsswitch/files/common/files_common.c 
b/usr/src/lib/nsswitch/files/common/files_common.c
--- a/usr/src/lib/nsswitch/files/common/files_common.c
+++ b/usr/src/lib/nsswitch/files/common/files_common.c
@@ -333,7 +333,7 @@ _nss_files_hash_destroy(files_hash_t *fh
  * other than the nscd; the consumption of swap space and memory is otherwise
  * unacceptable when the nscd is killed w/ a large passwd file (4M) active.
  * See 4031930 for details.
- * So we just use this psuedo function to enable the hashing feature.  Since
+ * So we just use this pseudo function to enable the hashing feature.  Since
  * this function name is private, we just create a function w/ the name
  *  __nss_use_files_hash in the nscd itself and everyone else uses the old
  * interface.
diff --git a/usr/src/lib/pkcs11/pkcs11_softtoken/common/softKeystore.c 
b/usr/src/lib/pkcs11/pkcs11_softtoken/common/softKeystore.c
--- a/usr/src/lib/pkcs11/pkcs11_softtoken/common/softKeystore.c
+++ b/usr/src/lib/pkcs11/pkcs11_softtoken/common/softKeystore.c
@@ -2161,7 +2161,7 @@ soft_gen_hmac_key(uchar_t *pPIN, soft_ob
 }
 
 /*
- * The token session is just a psuedo session (a place holder)
+ * The token session is just a pseudo session (a place holder)
  * to hold some information during encryption/decryption and
  * sign/verify operations when writing/reading the keystore
  * token object.
diff --git a/usr/src/stand/lib/tcp/tcp.c b/usr/src/stand/lib/tcp/tcp.c
--- a/usr/src/stand/lib/tcp/tcp.c
+++ b/usr/src/stand/lib/tcp/tcp.c
@@ -1808,7 +1808,7 @@ tcp_verify_cksum(mblk_t *mp)
        len = ntohs(iph->ip_len);
 
        /*
-        * Calculate the TCP checksum.  Need to include the psuedo header,
+        * Calculate the TCP checksum.  Need to include the pseudo header,
         * which is similar to the real IP header starting at the TTL field.
         */
        iph->ip_sum = htons(len - IP_SIMPLE_HDR_LENGTH);
@@ -6217,7 +6217,7 @@ tcp_set_cksum(mblk_t *mp)
        tcph = (tcpha_t *)(iph + 1);
        len = ntohs(iph->ip_len);
        /*
-        * Calculate the TCP checksum.  Need to include the psuedo header,
+        * Calculate the TCP checksum.  Need to include the pseudo header,
         * which is similar to the real IP header starting at the TTL field.
         */
        iph->ip_sum = htons(len - IP_SIMPLE_HDR_LENGTH);
diff --git a/usr/src/tools/cscope-fast/scanner.l 
b/usr/src/tools/cscope-fast/scanner.l
--- a/usr/src/tools/cscope-fast/scanner.l
+++ b/usr/src/tools/cscope-fast/scanner.l
@@ -87,7 +87,7 @@ static        int     *preifbraces;           /* brace count
 static int     *preifbraces;           /* brace count before #if */
 static int     parens;                 /* unmatched left parenthesis count */
 static BOOL    ppdefine;               /* preprocessor define statement */
-static BOOL    psuedoelif;             /* psuedo-#elif */
+static BOOL    pseudoelif;             /* pseudo-#elif */
 static BOOL    oldtype;                /* next identifier is an old type */
 static BOOL    rules;                  /* lex/yacc rules */
 static BOOL    sdl;                    /* SDL file */
@@ -204,14 +204,14 @@ number            \.?[0-9][.0-9a-fA-FlLuUxX]*
                        if (elseelif == YES) {
                                goto endif;
                        }
-                       psuedoelif = YES;
+                       pseudoelif = YES;
                        goto more;
                        /* NOTREACHED */
                }
 \#[ \t]*ifn?(def)?     { /* #if, #ifdef or #ifndef */
                        elseelif = NO;
-                       if (psuedoelif == YES) {
-                               psuedoelif = NO;
+                       if (pseudoelif == YES) {
+                               pseudoelif = NO;
                                goto elif;
                        }
                        /*
@@ -773,7 +773,7 @@ initscanner(char *srcfile)
        localdef = NO;          /* function/block local definition */
        parens = 0;             /* unmatched left parenthesis count */
        ppdefine = NO;          /* preprocessor define statement */
-       psuedoelif = NO;        /* psuedo-#elif */
+       pseudoelif = NO;        /* pseudo-#elif */
        oldtype = NO;           /* next identifier is an old type */
        rules = NO;             /* lex/yacc rules */
        sdl = NO;               /* SDL file */
diff --git a/usr/src/uts/common/fs/nfs/nfs_common.c 
b/usr/src/uts/common/fs/nfs/nfs_common.c
--- a/usr/src/uts/common/fs/nfs/nfs_common.c
+++ b/usr/src/uts/common/fs/nfs/nfs_common.c
@@ -69,7 +69,7 @@
 #include <rpc/svc.h>
 
 /*
- * The psuedo NFS filesystem to allow diskless booting to dynamically
+ * The pseudo NFS filesystem to allow diskless booting to dynamically
  * mount either a NFS V2, NFS V3, or NFS V4 filesystem.  This only implements
  * the VFS_MOUNTROOT op and is only intended to be used by the
  * diskless booting code until the real root filesystem is mounted.
diff --git a/usr/src/uts/common/inet/tcp/tcp.c 
b/usr/src/uts/common/inet/tcp/tcp.c
--- a/usr/src/uts/common/inet/tcp/tcp.c
+++ b/usr/src/uts/common/inet/tcp/tcp.c
@@ -8407,7 +8407,7 @@ tcp_header_init_ipv6(tcp_t *tcp)
        tcph->th_offset_and_rsrvd[0] = (5 << 4);
        /*
         * IP wants our header length in the checksum field to
-        * allow it to perform a single psuedo-header+checksum
+        * allow it to perform a single pseudo-header+checksum
         * calculation on behalf of TCP.
         * Include the adjustment for a source route when IPV6_RTHDR is set.
         */
diff --git a/usr/src/uts/common/io/ib/clients/ibd/ibd.c 
b/usr/src/uts/common/io/ib/clients/ibd/ibd.c
--- a/usr/src/uts/common/io/ib/clients/ibd/ibd.c
+++ b/usr/src/uts/common/io/ib/clients/ibd/ibd.c
@@ -69,8 +69,8 @@
  * and performance studies.
  *
  * none: h/w (Tavor) and driver does not do checksum, IP software must.
- * partial: driver does data checksum, IP must provide psuedo header.
- * perf_partial: driver uses IP provided psuedo cksum as data checksum
+ * partial: driver does data checksum, IP must provide pseudo header.
+ * perf_partial: driver uses IP provided pseudo cksum as data checksum
  *              (thus, real checksumming is not done).
  */
 typedef enum {
@@ -1529,7 +1529,7 @@ ibd_hash_by_id(void *hash_data, mod_hash
        /*
         * If the input address is 4 byte aligned, we can just dereference
         * it. This is most common, since IP will send in a 4 byte aligned
-        * IP header, which implies the 24 byte IPoIB psuedo header will be
+        * IP header, which implies the 24 byte IPoIB pseudo header will be
         * 4 byte aligned too.
         */
        if ((ptraddr & 3) == 0)
diff --git a/usr/src/uts/common/io/ib/ibnex/ibnex.c 
b/usr/src/uts/common/io/ib/ibnex/ibnex.c
--- a/usr/src/uts/common/io/ib/ibnex/ibnex.c
+++ b/usr/src/uts/common/io/ib/ibnex/ibnex.c
@@ -3596,7 +3596,7 @@ ibnex_pseudo_initnodes()
                if (node_type && strcmp(node_type, "merge") == 0)
                        nodep->node_data.pseudo_node.pseudo_merge_node = 1;
 
-               /* Mark this as a new psuedo node */
+               /* Mark this as a new pseudo node */
                nodep->node_data.pseudo_node.pseudo_new_node = 1;
 
                IBTF_DPRINTF_L3("ibnex", "\tpseudo_initnodes: unit addr = %s"
diff --git a/usr/src/uts/common/io/lvm/mirror/mirror.c 
b/usr/src/uts/common/io/lvm/mirror/mirror.c
--- a/usr/src/uts/common/io/lvm/mirror/mirror.c
+++ b/usr/src/uts/common/io/lvm/mirror/mirror.c
@@ -332,7 +332,7 @@ mirror_geterror(mm_unit_t *un, int *smi,
                            (sm->sm_dev, sm, ci);
                        /*
                         * if called from any routine but probe, we check for
-                        * MDM_S_ISOPEN flag. Since probe does a pseduo open,
+                        * MDM_S_ISOPEN flag. Since probe does a pseudo open,
                         * it sets MDM_S_PROBEOPEN flag and we test for this
                         * flag. They are both exclusive tests.
                         */
diff --git a/usr/src/uts/common/sys/fs/pc_fs.h 
b/usr/src/uts/common/sys/fs/pc_fs.h
--- a/usr/src/uts/common/sys/fs/pc_fs.h
+++ b/usr/src/uts/common/sys/fs/pc_fs.h
@@ -200,7 +200,7 @@ struct pcfs {
 #define        PCFS_NOCHK              0x800   /* don't resync fat on error */
 #define        PCFS_BOOTPART           0x1000  /* boot partition type */
 #define        PCFS_HIDDEN             0x2000  /* show hidden files */
-#define        PCFS_PCMCIA_NO_CIS      0x4000  /* PCMCIA psuedo floppy */
+#define        PCFS_PCMCIA_NO_CIS      0x4000  /* PCMCIA pseudo floppy */
 #define        PCFS_FOLDCASE           0x8000  /* fold filenames to lowercase 
*/
 #define        PCFS_FAT32              0x10000 /* 32 bit FAT */
 #define        PCFS_IRRECOV            0x20000 /* FS was messed with during 
write */
diff --git a/usr/src/uts/common/sys/ptem.h b/usr/src/uts/common/sys/ptem.h
--- a/usr/src/uts/common/sys/ptem.h
+++ b/usr/src/uts/common/sys/ptem.h
@@ -36,7 +36,7 @@ extern "C" {
 
 /*
  * The ptem data structure used to define the global data
- * for the psuedo terminal emulation streams module
+ * for the pseudo terminal emulation streams module
  */
 struct ptem {
        tcflag_t cflags;        /* copy of c_cflags */
diff --git a/usr/src/uts/i86pc/os/ddi_impl.c b/usr/src/uts/i86pc/os/ddi_impl.c
--- a/usr/src/uts/i86pc/os/ddi_impl.c
+++ b/usr/src/uts/i86pc/os/ddi_impl.c
@@ -1966,7 +1966,7 @@ get_vga_properties(void)
  *
  * Trying to assemble root file system drivers as we are booting from
  * devconf will fail if the kernel driver is basing its name_addr's on the
- * psuedo-node device info while the bootpath passed up from bootconf is using
+ * pseudo-node device info while the bootpath passed up from bootconf is using
  * reality-based name_addrs.  We help the boot along in this case by
  * looking at the pre-bootconf bootpath and determining if we would have
  * successfully matched if that had been the bootpath we had chosen.
diff --git a/usr/src/uts/sun4u/cpu/us3_common_asm.s 
b/usr/src/uts/sun4u/cpu/us3_common_asm.s
--- a/usr/src/uts/sun4u/cpu/us3_common_asm.s
+++ b/usr/src/uts/sun4u/cpu/us3_common_asm.s
@@ -416,7 +416,7 @@ vac_flushpage(pfn_t pfnum, int vcolor)
  * vac_flushpage(pfnum, color)
  *     Flush 1 8k page of the D-$ with physical page = pfnum
  *     Algorithm:
- *             The cheetah dcache is a 64k psuedo 4 way accaociative cache.
+ *             The cheetah dcache is a 64k pseudo 4 way accaociative cache.
  *             It is virtual indexed, physically tagged cache.
  */
        .seg    ".data"
diff --git a/usr/src/uts/sun4u/io/wrsm/wrsm_cf.c 
b/usr/src/uts/sun4u/io/wrsm/wrsm_cf.c
--- a/usr/src/uts/sun4u/io/wrsm/wrsm_cf.c
+++ b/usr/src/uts/sun4u/io/wrsm/wrsm_cf.c
@@ -1223,7 +1223,7 @@ err_return:
 
 /*
  * Called as a result of an WRSM_INITIALCFG ioctl() call to the wrsm
- * admin psuedo driver.  The arg is a pointer to a wrsm_admin_arg_config_t
+ * admin pseudo driver.  The arg is a pointer to a wrsm_admin_arg_config_t
  * structure which contains the address and size of a wrsm_controller_t.
  * If successfull, this function brings the controller data in from user
  * space and passes it to wsrm_nc_initialcfg().
diff --git a/usr/src/uts/sun4u/serengeti/io/sbdp_error.c 
b/usr/src/uts/sun4u/serengeti/io/sbdp_error.c
--- a/usr/src/uts/sun4u/serengeti/io/sbdp_error.c
+++ b/usr/src/uts/sun4u/serengeti/io/sbdp_error.c
@@ -267,7 +267,7 @@ sbdp_inject_error(const char *func_name,
        case SBDP_IE_RANDOM:
                /*
                 * Since we usually only need a binary type of return
-                * value, use lbolt to generate the psuedo random
+                * value, use lbolt to generate the pseudo random
                 * response.
                 */
                value = (-(int)(lbolt % 2));
diff --git a/usr/src/uts/sun4v/vm/mach_sfmmu.h 
b/usr/src/uts/sun4v/vm/mach_sfmmu.h
--- a/usr/src/uts/sun4v/vm/mach_sfmmu.h
+++ b/usr/src/uts/sun4v/vm/mach_sfmmu.h
@@ -155,13 +155,13 @@ 9:
        or      ttarget, scr1, ttarget
 
 /*
- * Synthesize/get data/instruction psuedo tag access register values
+ * Synthesize/get data/instruction pseudo tag access register values
  * from the MMU fault area (context is 0 for kernel, 1 for invalid, 2 for user)
  *
  * In:
  *   dtagacc, itagacc, scr1, scr2 = scratch registers
  * Out:
- *   dtagacc = MMU data tag access register value w/psuedo-context
+ *   dtagacc = MMU data tag access register value w/pseudo-context
  *   itagacc = MMU instruction tag access register value w/pseudo-context
  */
 #define        GET_MMU_BOTH_TAGACC(dtagacc, itagacc, scr1, scr2)       \

Reply via email to
diff --git a/usr/src/cmd/uniq/uniq.c b/usr/src/cmd/uniq/uniq.c
--- a/usr/src/cmd/uniq/uniq.c
+++ b/usr/src/cmd/uniq/uniq.c
@@ -113,12 +113,12 @@ main(int argc, char *argv[])
        /* handle all of uniq's arguments via getopt(3C):               */
        while ((c = getopt(mac, mav, "n:m:cduf:s:")) != EOF) {
                switch (c) {
-               case 'n':       /* parseargs() psuedo argument for -#   */
+               case 'n':       /* parseargs() pseudo argument for -#   */
                        modeflag |= MODEFLAG_NM;
                        fields = atoi(optarg);
                        break;
 
-               case 'm':       /* parseargs() psuedo argument for +#   */
+               case 'm':       /* parseargs() pseudo argument for +#   */
                        modeflag |= MODEFLAG_NM;
                        letters = atoi(optarg);
                        break;
@@ -405,7 +405,7 @@ char *p, *s;
  *             -# (a.k.a. -n)  to "-n #"
  *             +# (a.k.a. +n)  to "-m #"
  *
  *     E.g. -3 gets changed to the psuedo argument "-n 3".
  *
  *     N.B.: we *DON'T* map -# to -f, nor +# to -s, as -/+ usage is
  *             mutually exclusive with -f & -s according to the
@@ -424,7 +424,7 @@ char **av;
        int fflag;              /* 0 = haven't found input/output file  */
        int minusflag;          /* !0 = have hit a "--": end of flags   */
        size_t sz;              /* size of the argument                 */
-       size_t mav_sz;          /* size of our psuedo argument space    */
+       size_t mav_sz;          /* size of our pseudo argument space    */
 
        i = mac = fflag = minusflag = 0;        /* proper initializations */
 
@@ -405,7 +405,7 @@ char *p, *s;
  *             +# (a.k.a. +n)  to "-m #"
  *
- *     E.g. -3 gets changed to the psuedo argument "-n 3".
+ *     E.g. -3 gets changed to the pseudo argument "-n 3".
  *
  *     N.B.: we *DON'T* map -# to -f, nor +# to -s, as -/+ usage is